API docs for “spamfighter.core.message.serialize.TransitMessage”

# Class s.c.m.s.TransitMessage(object):

Part of spamfighter.core.message.serialize View Source View In Hierarchy

Вариант сообщения, которое передается в сериализованном представлении через параметры команд.

Instance Variables | serialized | сериализованное представление сообщения (type: `dict` )

Method | __init__ | Конструктор.
Method | serialize | Сериализовать сообщение.
Class Method | unserialize | Десериализовать сообщение.
Method | getMessage | Окончательно десериализовать сообщение относительно домена.
Method | __repr__ | Undocumented
Method | __eq__ | Undocumented

def __init__(self, message=None, serialized=None): (source)
Конструктор.

Может быть передано либо сериализованное представление сообщения (`serialized`), либо исходное сообщение (`message`).

Parameters | message | исходное сообщение (type: `IMessage` )
| serialized | сериализованное представление сообщения (type: `dict` )

def serialize(self): (source)
Сериализовать сообщение.

@classmethod
def unserialize(cls, serialized): (source)
Десериализовать сообщение.

Parameters | serialized | сериализованное представление сообщения (type: `dict` )

def getMessage(self, domain): (source)
Окончательно десериализовать сообщение относительно домена.

Parameters | domain | домен, относительно которого десериализуется сообщение (type: `spamfighter.interfaces.IDomain` )
Returns | десериализованное сообщение (type: `IMessage` )

def __repr__(self): (source)
Undocumented
def __eq__(self, other): (source)
Undocumented